#!/bin/sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

#
# This script will install UFM on the ITME appliance.
# 

echo "====================================================="
echo "+++             UFM Installation                  +++"
echo "====================================================="

SRC_DIR=`dirname $0`
HOME=`cd $SRC_DIR; pwd`
UFM_IMG=`ls $HOME/iufm*tgz`
UFM_BASE=`basename $UFM_IMG .tgz`
UFM_DIR=/tmp/ufm/$UFM_BASE
UFM_LICENSE=volt-ufm-license_evaluation_good_date.lic
UFM_INST_SCRIPT=./install.sh
GV_CONFIG_DIR=/opt/ibm/director/data/ufm
GV_OVERRIDE=gv_override.cfg
DB_PROPERTIES=/opt/ibm/director/lwi/conf/overrides/database.properties
DB_PROPERTIES2=/opt/ibm/director/lwi/conf/overrides/dbvariables.properties
UFM_LICENSE_DIR=/opt/ufm/files/licenses
UFM_DAEMON=/etc/init.d/ufmd
NC_CHDB_SCRIPT=NCChangeDBCfg.sh
DBCONF_EXT=/opt/ibm/director/proddata/dbconfig/ext
DB2_DIR=/opt/ibm/director/bin
DB2_STARTED=/opt/db2_started

#
# PROPERTIES
#
echo "Known variables: "
echo UFM installer: $UFM_IMG
echo UFM source location: $UFM_DIR
echo UFM license: $UFM_LICENSE
echo UFM install script: $UFM_INST_SCRIPT
echo UFM daemon: $UFM_DAEMON

#
# Installing prerequisite RPMs
#

echo "`date +'[%T %Z]'` Installing prerequisite RPMs"

cd $HOME/prereqs
rpm -iv python-pexpect-2.3-23.17.x86_64.rpm
rpm -iv python-zopeinterface-3.3.0-79.17.x86_64.rpm
rpm -iv python-pam-0.5.0-3.18.x86_64.rpm
rpm -iv python-serial-2.4-1.17.x86_64.rpm
rpm -iv python-twisted-8.0.1-1.22.x86_64.rpm
rpm -iv python-twisted-conch-8.1.0-1.22.x86_64.rpm 
rpm -iv python-twisted-web-8.0.0-1.22.x86_64.rpm

#
# Copying configuration properties to gv_override.cfg
#

echo "`date +'[%T %Z]'` Copying database properties"

cd $HOME
mkdir -p $GV_CONFIG_DIR
cp $GV_OVERRIDE  $GV_CONFIG_DIR

awk '
/^rcs.dbname/ {print "db2.dbname = "$3 >> file }
/^rcs.dbuser/ {print "db2.dbuser = "$3 >> file }
/^rcs.dbpassword/ {print "db2.dbpassword = "$3 >> file }
/^rcs.dbservername/ {print "db2.dbservername = "$3 >> file }
/^rcs.dbport/ {print "db2.dbport = "$3 >> file }
/^rcs.dbdrivertype/ {print "db2.dbdrivertype = "$3 >> file }
' file=$GV_CONFIG_DIR/$GV_OVERRIDE $DB_PROPERTIES

awk '
/^dblibpath/ {print >> file }
' file=$GV_CONFIG_DIR/$GV_OVERRIDE $DB_PROPERTIES2

#
# Copying image to local directory and unpacking UFM
#

echo "`date +'[%T %Z]'` Unpacking UFM in current directory and cd into install directory"

mkdir -p /tmp/ufm 
tar -xzvf $UFM_IMG -C /tmp/ufm
[ $? -ne 0 ] && exit 2

if [ ! -d $UFM_DIR ]; then
	echo "Failed to unzip and extract UFM installer. "
	echo "$UFM_DIR doesn't exist." 
	exit 3
fi

#
# Check DB2 status
#
$DB2_DIR/smdb status | grep Active
if [ $? -eq 0 ]
then
   echo "No need to start DB2"
else
   echo "Start DB2"
   $DB2_DIR/smdb start
   touch $DB2_STARTED
   sleep 8
fi

#
# Check DB2 status again
#
#
#
$DB2_DIR/smdb status | grep Active
if [ $? -eq 0 ]
then
   
   #Check if previous version of IUFM installed. If it installed, try to stop IUFM service.
   if [  -d /opt/ufm/version ]; then
     /etc/init.d/ufmd stop
   else
     echo "Previous version of IUFM is not installed"
   fi    
    
   # Installing and configuring UFM
   #
     
   echo "`date +'[%T %Z]'` Running UFM installer "

   cd $UFM_DIR
   if [ -x ${UFM_INST_SCRIPT} ]; then
	   ${UFM_INST_SCRIPT} -q -f $GV_CONFIG_DIR/$GV_OVERRIDE
   else 
      echo "Unable to execute UFM installer."
	  exit 4
   fi
else
    echo "DB2 not started. Aborting UFM installation"	
    exit 4	
fi

echo "Additional logic added to fix IUFM startup issue"
# Ensure Apache SSL is enabled.
sed 's/APACHE_SERVER_FLAGS=""/APACHE_SERVER_FLAGS="SSL"/g' /etc/sysconfig/apache2> /tmp/tempApache2.txt
cp /tmp/tempApache2.txt /etc/sysconfig/apache2
rm /tmp/tempApache2.txt

# Tactical fix required for Apache server.  Comment out these lines since these ports are in use.  Component that uses these ports
# should eventually handle this.
sed '/Listen\b\s80\b/c # Listen 80' -i /etc/apache2/listen.conf
sed '/Listen\b\s443\b/c # Listen 443' -i /etc/apache2/listen.conf

 [ $? -ne 0 ] && cat /tmp/ufm*log
 
# If I-UFM Apache setup files exist here, then I-UFM Apache setup worked.
# Copying license file and UFM plugins
#

echo "`date +'[%T %Z]'` Copying license file and starting UFM"
cd $HOME
cp ${UFM_LICENSE} ${UFM_LICENSE_DIR}

#echo "`date +'[%T %Z]'` Copying UFM plugins and features into NetworkControl directory"

#unzip -d /opt/ibm/director/lwi/runtime/director/eclipse ufm_plugins.bin.zip 


if [ ! -d $DBCONF_EXT ]; then
	mkdir -p $DBCONF_EXT
fi
cp $NC_CHDB_SCRIPT $DBCONF_EXT
chmod 500 $DBCONF_EXT/$NC_CHDB_SCRIPT

# Code added to load DB2 libraries
if [ -f /etc/ld.so.conf.d/ibm_db2.conf ]
then
   echo "ibm_db2.conf files exist"
   echo  /opt/ibm/director/db2/lib32/ >>/etc/ld.so.conf.d/ibm_db2.conf
   echo /opt/ibm/director/db2/lib64/ >>/etc/ld.so.conf.d/ibm_db2.conf
   ldconfig
else
   touch /etc/ld.so.conf.d/ibm_db2.conf
   echo  /opt/ibm/director/db2/lib32/ >>/etc/ld.so.conf.d/ibm_db2.conf
   echo /opt/ibm/director/db2/lib64/ >>/etc/ld.so.conf.d/ibm_db2.conf
   ldconfig
fi

#
# Cleaning up and we're done!
#

rm -r /tmp/ufm
chkconfig ufmd off
chkconfig ufmha off

# Stop DB2 if it started through UFM
#
if [ -f $DB2_STARTED ]
then
    su - db2inst1 -c 'db2 list applications'
    su - db2inst1 -c 'db2 list active databases'
    su - db2inst1 -c 'db2 force applications all'
    $DB2_DIR/smdb stop
	rm -rf $DB2_STARTED
else
   echo "No need to stop DB2"
fi

#/opt/ufm/scripts/ufmconfig --set_credential_path /opt/ibm/director/proddata/ufm-security.properties	

echo "`date +'[%T %Z]'` UFM installation complete"

# If I-UFM Apache setup files exist here but not in runtime FSM VM, then FSM build clean process 
# may have a problem.  If the files don't exist, NC clean up above may have a problem.

echo "====================================================="
echo "+++             UFM INSTALLATION END              +++"
echo "====================================================="
